@@ -1,6 +1,6 @@
 # Author: Babak Naimi, naimi.b@gmail.com
 # Date :  July 2016
-# Version 1.4
+# Version 1.5
 # Licence GPL v3
 
 setMethod ('show' , 'sdmdata',
@@ -65,7 +65,6 @@ setMethod ('show' , '.sdmCorSetting',
            }
 )
 #---------------------
-
 setMethod ('show' , 'sdmModels',
            function (object) {
              if (!.sdmOptions$getOption('sdmLoaded')) .addMethods()
@@ -109,17 +108,31 @@ setMethod ('show' , 'sdmModels',
              }
              
              a <- ''
+             a2 <- c()
              for (i in sp) {
                aa <- length(unlist(strsplit(i,'')))
                la <- 15
-               if (length(aa) >= 15) la <- length(aa) + 3
+               if (aa >= 15) la <- aa + 3
                a <- paste(a,i,paste(rep(' ',la - aa),collapse=''),collapse='')
-              }
+               a2 <- c(a2,la)
+             }
+             a2 <- a2 - 3
              cat(paste('method        ',a,collapse='|'),'\n')
              cat(paste(rep('-',length(unlist(strsplit(a,'')))+5),collapse=''),'\n')
-             
              for (i in seq_along(mo)) {
-               cat(paste(mo[i],paste(rep(' ',10 - length(unlist(strsplit(mo[i],'')))),collapse=''),' : ',paste(rep(' ',3),collapse=''),sep='')  , paste(p2(mo[i]),collapse='       |     '), '%\n')
+               a3 <- c()
+               a4 <- ''
+               p2.mo <- p2(mo[i])
+               if (length(a2) > 1) {
+                 for (j in 1:(length(a2)-1)) a3 <- c(a3,paste(paste(rep(' ',a2[j]/2),collapse=''),'|',paste(rep(' ',a2[j+1]/2),collapse=''),collapse='')) 
+               } else {
+                 a3 <- paste(rep(' ',a2),collapse='') 
+               }
+               
+               
+               a3 <- c(paste(rep(' ',a2[1]/2-2),collapse=''),a3)
+               for (j in 1:length(a2)) a4 <- paste(c(a4,a3[j],p2.mo),collapse='')
+               cat(paste(mo[i],paste(rep(' ',10 - length(unlist(strsplit(mo[i],'')))),collapse=''),' : ',paste(rep(' ',3),collapse=''),a4,sep='')  , '  %\n')
              }
              wtest <- colnames(mi)[9:7][which(as.matrix(mi[1,c(9,8,7)]))[1]]
              
@@ -139,8 +152,8 @@ setMethod ('show' , 'sdmModels',
                  cat('model performance (per species), using independent test dataset:\n')
                else
                  cat('model performance (per species), using training test dataset:\n')
-              } 
-               
+             } 
+             
              cat('--------------------------------------------------------------------\n')
              p <- function(x,sp) {
                a <- c()
@@ -173,3 +186,4 @@ setMethod ('show' , 'sdmModels',
              }
            }
 )
+
